==> estateplat-common-1.2.3-20180202.065337-24-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmhtBdcdjjsf.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "ls_fcjy_clf_mmht_bdcdjjsf")
public class LsFcjyClfMmhtBdcdjjsf implements InsertVo {

    @Id
    private String id;//主键
    private String htid;//合同id
    private Date bldjqx;//办理登记期限
    private String sfzdsm;//税费承担说明
    private Date zyygdjrq;//转移预告登记日期
    private Integer zyygzxqx;//转移预告注销期限
    private Double djwyj;//登记违约金

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Date getBldjqx() {
        return bldjqx;
    }

    public void setBldjqx(Date bldjqx) {
        this.bldjqx = bldjqx;
    }

    public String getSfzdsm() {
        return sfzdsm;
    }

    public void setSfzdsm(String sfzdsm) {
        this.sfzdsm = sfzdsm;
    }

    public Date getZyygdjrq() {
        return zyygdjrq;
    }

    public void setZyygdjrq(Date zyygdjrq) {
        this.zyygdjrq = zyygdjrq;
    }

    public Integer getZyygzxqx() {
        return zyygzxqx;
    }

    public void setZyygzxqx(Integer zyygzxqx) {
        this.zyygzxqx = zyygzxqx;
    }

    public Double getDjwyj() {
        return djwyj;
    }

    public void setDjwyj(Double djwyj) {
        this.djwyj = djwyj;
    }
}

==> estateplat-common-1.2.3-20180302.073208-38-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmhtBdcdjjsf.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "ls_fcjy_clf_mmht_bdcdjjsf")
public class LsFcjyClfMmhtBdcdjjsf implements InsertVo {

    @Id
    private String id;//主键
    private String htid;//合同id
    private Date bldjqx;//办理登记期限
    private String sfcd;//税费承担
    private String sfzdsm;//税费承担说明
    private Date zyygdjrq;//转移预告登记日期
    private Integer zyygzxqx;//转移预告注销期限
    private Double djwyj;//登记违约金

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Date getBldjqx() {
        return bldjqx;
    }

    public void setBldjqx(Date bldjqx) {
        this.bldjqx = bldjqx;
    }

    public String getSfcd() {
        return sfcd;
    }

    public void setSfcd(String sfcd) {
        this.sfcd = sfcd;
    }

    public String getSfzdsm() {
        return sfzdsm;
    }

    public void setSfzdsm(String sfzdsm) {
        this.sfzdsm = sfzdsm;
    }

    public Date getZyygdjrq() {
        return zyygdjrq;
    }

    public void setZyygdjrq(Date zyygdjrq) {
        this.zyygdjrq = zyygdjrq;
    }

    public Integer getZyygzxqx() {
        return zyygzxqx;
    }

    public void setZyygzxqx(Integer zyygzxqx) {
        this.zyygzxqx = zyygzxqx;
    }

    public Double getDjwyj() {
        return djwyj;
    }

    public void setDjwyj(Double djwyj) {
        this.djwyj = djwyj;
    }
}
